##############################################################################
#   Title: appendix_accountants.R
# Purpose: 
#   Owner: EZ
# Created: 2020-04-07
##############################################################################

init <- function() {
  
  # Configure environment.
  MAINROOT <<- path.expand(".")
  FIG_OUTDIR <<- file.path(MAINROOT, "drafts/accountants/12pub/figures")
  TAB_OUTDIR <<- file.path(MAINROOT, "drafts/accountants/12pub/tables")
  DATADIR <<- file.path(MAINROOT, "PATH/TO/OUTSIDEDATA")
  
  # Add packages
  require(data.table)
  require(ggplot2)
  require(ggthemes)
  
  # Graph parameters.
  WIDTH <<- 6.5
  HEIGHT <<- 4.25
}


# Figure A2
graph_complicated <- function() { # %<
  
  data = data.table(read.csv(file.path(DATADIR,
                                       "size_claim_amt.csv")))
  
  reshaped <- rbind(data[, list(X, v = unclaimed_noamt, N = Nnoamt/N,
                                Group = "Unclaimed w/No AMT")], 
                    data[, list(X, v = unclaimed_amt, N = Namt/N,
                                Group = "Unclaimed w/AMT")])
  reshaped$Group = factor(reshaped$Group, 
                          levels = c("Unclaimed w/No AMT",
                                   "Unclaimed w/AMT"))
  
  ggsave(filename = file.path(FIG_OUTDIR, "size_claim_amt.pdf"),
         width = WIDTH, height = HEIGHT, plot =
           ggplot() +
           theme_few() +
           labs(x = "Size Percentiles", 
                y = "Share (Percent)") +
           geom_bar(data = reshaped, aes(x = reorder(as.character(X), X), y = v,
                                       fill = Group), 
                    position = "dodge",
                    stat = "identity") + 
           geom_text(data = reshaped[Group == "Unclaimed w/AMT"], aes(x = reorder(as.character(X), X), y = v,
                                                                  label = round(N, 2)), vjust = -.3, size = 3) + 
           scale_x_discrete(labels = c("1" ="1-10", "2" = "11-20",
                                      "3" = "21-30", "4" = "31-40",
                                      "5" = "41-50", "6" = "51-60",
                                      "7" = "61-70", "8" = "71-80",
                                      "9" = "81-90", "10" = "91-92",
                                      "11" = "93-94", "12" = "95-96",
                                      "13" = "97-98", "14" = "99-100")) +
           scale_fill_manual(values = c(rgb(70, 70, 255, max = 255), 
                                      rgb(204, 204, 255, max = 255))) +
           theme(legend.position = "bottom", legend.title = element_blank()) +
           scale_y_continuous(limits = c(0,1)) +
           theme(axis.text.x = element_text(angle = -20, hjust = 0.55, vjust = 0.35, color = "black")) + 
           theme(axis.text.y = element_text(color = "black"))
  )
  
  # Repeat for Tax Credit firms
  data = data.table(read.csv(file.path(DATADIR,
                                       "size_claim_complex.csv")))
  
  reshaped <- rbind(data[, list(X, v = unclaimed_notc, N = Nnotc/N,
                                Group = "Unclaimed w/No Tax Credits")], 
                    data[, list(X, v = unclaimed_tc, N = Ntc/N,
                                Group = "Unclaimed w/Tax Credits")])
  reshaped$Group = factor(reshaped$Group, 
                          levels = c("Unclaimed w/No Tax Credits",
                                   "Unclaimed w/Tax Credits"))
  
  ggsave(filename = file.path(FIG_OUTDIR, "size_claim_tc.pdf"),
         width = WIDTH, height = HEIGHT, plot =
           ggplot() +
           theme_few() +
           labs(x = "Size Percentiles", 
                y = "Share (Percent)") +
           geom_bar(data = reshaped, aes(x = reorder(as.character(X), X), y = v,
                                       fill = Group), 
                    position = "dodge",
                    stat = "identity") + 
           geom_text(data = reshaped[Group == "Unclaimed w/No Tax Credits"], aes(x = reorder(as.character(X), X), y = v,
                                                                             label = round(N, 2)), vjust = -.3, size = 3) +
           scale_x_discrete(labels = c("1" ="1-10", "2" = "11-20",
                                      "3" = "21-30", "4" = "31-40",
                                      "5" = "41-50", "6" = "51-60",
                                      "7" = "61-70", "8" = "71-80",
                                      "9" = "81-90", "10" = "91-92",
                                      "11" = "93-94", "12" = "95-96",
                                      "13" = "97-98", "14" = "99-100")) +
           scale_fill_manual(values = c(rgb(70, 70, 255, max = 255), 
                                      rgb(204, 204, 255, max = 255))) +
           theme(legend.position = "bottom", legend.title = element_blank()) +
           scale_y_continuous(limits = c(0,1)) +
           theme(axis.text.x = element_text(angle = -20, hjust = 0.55, vjust = 0.35, color = "black")) + 
           theme(axis.text.y = element_text(color = "black"))
         
  )
  
} # %>

# Figure A1 - Code available in inside environment

# Table A3 - Runs in inside environment
table_npv_ratio <- function() {
  
  # load 
  db <- dbConnect(SQLite(), dbname="PATH/TO/data.db")
  data = dbGetQuery( db , "select * from npv_sim_ub;")
  data = data.table(data, key="ein,nol_yr")
  
  
  # 3 percent interest rate
  row_3r = data[, list(mean(npv_cf_3r/npv_cb_3r<1),
                       mean(npv_cf_3r/npv_cb_3r<0.9),
                       mean(npv_cf_3r/npv_cb_3r<0.8),
                       mean(npv_cf_3r/npv_cb_3r<0.7))]
  
  # 5 percent interest rate
  row_5r = data[, list(mean(npv_cf_5r/npv_cb_5r<1),
                       mean(npv_cf_5r/npv_cb_5r<0.9),
                       mean(npv_cf_5r/npv_cb_5r<0.8),
                       mean(npv_cf_5r/npv_cb_5r<0.7))]
  
  # 7 percent interest rate
  row_7r = data[, list(mean(npv_cf_7r/npv_cb_7r<1),
                       mean(npv_cf_7r/npv_cb_7r<0.9),
                       mean(npv_cf_7r/npv_cb_7r<0.8),
                       mean(npv_cf_7r/npv_cb_7r<0.7))]
  
  # 9 percent interest rate
  row_9r = data[, list(mean(npv_cf_9r/npv_cb_9r<1),
                       mean(npv_cf_9r/npv_cb_9r<0.9),
                       mean(npv_cf_9r/npv_cb_9r<0.8),
                       mean(npv_cf_9r/npv_cb_9r<0.7))]
  
  # combine results
  combine = as.matrix(rbind(row_3r, row_5r, row_7r, row_9r))
  combine = formatC(combine, format='f', digits=4)
  colnames(combine) = c( "ratio<1", "ratio<0.9", "ratio<0.8", "ratio<0.7")
  combine = data.table(combine)
  combine$interest_rate = c( "3r", "5r", "7r", "9r")
  
  # save table
  text = latexTabular(combine)
  write(text, file = "/npv_ratio_matrix_all_1998-2002.tex")
  write.csv(combine, file = "/npv_ratio_matrix_all_1998-2002.csv")
  
}


################################################################################ 
# Main
################################################################################ 
main <- function() {
  
  init()
  
  # Outside R programs.
  graph_complicated()

  # Inside R programs.
  graph_lobs_vs_lsim()
  table_npv_ratio()
}

main
